RDFCalendar.Parsers.iCalendarParser

Package RDFCalendar :: Module Parsers :: Class iCalendarParser |
[show private | hide private]
[frames | no frames]

## Class iCalendarParser

    An iCalendar parser.

Method Summary
| ``decode`(self, value, encoding)` Decode the 'value' with the given 'encoding'.
| `get_details(self, values)`
| ``parse`(self, f, store, name, uriref)` Parse the contents of the file 'f', looking for calendar information to be recorded in the given 'store'.
| ``parse_attribute_text`(self, f)` Using the file 'f', return the attribute name, attribute modifiers/properties, and a list containing value information for the attribute information in the file.
| ``parse_element`(self, f, store, label, existing_node, uriref)` Parse the object being read from the file 'f', recording the details in the given 'store'.

Method Details

### decode(self, value, encoding)
    Decode the 'value' with the given 'encoding'.

### parse(self, f, store, name=None, uriref=None)
    Parse the contents of the file 'f', looking for calendar information to be
    recorded in the given 'store'. If the optional 'name' is specified, tag the
    calendar with that information. If the optional 'uriref' is supplied, use the
    value to override any unique identifier provided in the parsed file.

### parse_attribute_text(self, f)
    Using the file 'f', return the attribute name, attribute
    modifiers/properties, and a list containing value information for the
    attribute information in the file.

### parse_element(self, f, store, label, existing_node=None, uriref=None)
    Parse the object being read from the file 'f', recording the details in
    the given 'store'. The 'label' is used to recognise the end of the object
    definition. If an 'existing_node' is supplied, no new node is created for
    the element, but dependent elements are added to the given 'existing_node'.
    If an 'uriref' is supplied, use the value to override any unique identifier
    provided in the parsed file.
    The last line read from the file should have been the start of the object
    definition.

Generated by Epydoc 2.1 on Tue Sep 18 23:33:17 2007 | http://epydoc.sf.net